@@ -15,7 +15,11 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.accesscontrol.util;
 
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileNotFoundException;
 import java.io.IOException;
+import java.util.Properties;
 
 import javax.management.InstanceNotFoundException;
 import javax.management.MBeanException;
@@ -58,10 +62,15 @@ public class LdapConnectionManager {
 	 */
     private static final String OPERATION_NAME = "putMessage";
 	
-    /** プロバイダへの再接続間隔 */
-	private static final int PROVIDER_CONNECT_INTERVAL = 60000;
+	/** プロバイダへの再接続間隔 */
+	private static final String LDAP_PROVIDER_CONNECT_INTERVAL_KEY = "common.ldap.reconnect.interval";
+	private static final int PROVIDER_CONNECT_INTERVAL_DEFAULT = 60000;
+	private static int PROVIDER_CONNECT_INTERVAL = PROVIDER_CONNECT_INTERVAL_DEFAULT;
+	
 	/** 再接続回数 */
-	private static final int RECONNECT_MAX = 5;
+	private static final String LDAP_RECONNECT_RETRIES_KEY = "common.ldap.reconnect.retries";
+	private static final int RECONNECT_MAX_DEFAULT = 5;
+	private static int RECONNECT_MAX = RECONNECT_MAX_DEFAULT;
 	
 	/** プロバイダ接続フラグ */
     private static boolean m_provider = true;
@@ -74,6 +83,74 @@ public class LdapConnectionManager {
     
 	private static LdapConnectionManager m_instance = null;
 
+	static {
+		Properties properties = new Properties();
+		
+		String etcdir = System.getProperty("hinemos.manager.etc.dir");
+		String propertyFile = etcdir + File.separator + "hinemos.properties";
+		
+		PROVIDER_CONNECT_INTERVAL = PROVIDER_CONNECT_INTERVAL_DEFAULT;
+		RECONNECT_MAX = RECONNECT_MAX_DEFAULT;
+		
+		try {
+			// 設定ファイルからパラメータと値を読み込む
+			properties.load(new FileInputStream(propertyFile));
+			
+			if (properties.containsKey(LDAP_PROVIDER_CONNECT_INTERVAL_KEY)) {
+				try {
+					PROVIDER_CONNECT_INTERVAL = Integer.parseInt(properties.getProperty(LDAP_PROVIDER_CONNECT_INTERVAL_KEY));
+					if (PROVIDER_CONNECT_INTERVAL <= 0) {
+						if (m_log.isWarnEnabled()) {
+							m_log.warn("invalid ldap reconnect interval. (" + LDAP_PROVIDER_CONNECT_INTERVAL_KEY + "=" + properties.getProperty(LDAP_PROVIDER_CONNECT_INTERVAL_KEY) + ")");
+						}
+						PROVIDER_CONNECT_INTERVAL = PROVIDER_CONNECT_INTERVAL_DEFAULT;
+					}
+				} catch (NumberFormatException e) {
+					if (m_log.isWarnEnabled()) {
+						m_log.warn("invalid ldap reconnect interval. (" + LDAP_PROVIDER_CONNECT_INTERVAL_KEY + "=" + properties.getProperty(LDAP_PROVIDER_CONNECT_INTERVAL_KEY) + ")", e);
+					}
+				}
+			} else {
+				if (m_log.isInfoEnabled()) {
+					m_log.info("ldap reconnect interval is not defined. (" + LDAP_PROVIDER_CONNECT_INTERVAL_KEY + ")");
+				}
+			}
+			
+			if (properties.containsKey(LDAP_RECONNECT_RETRIES_KEY)) {
+				try {
+					RECONNECT_MAX = Integer.parseInt(properties.getProperty(LDAP_RECONNECT_RETRIES_KEY));
+					if (RECONNECT_MAX < 0) {
+						if (m_log.isWarnEnabled()) {
+							m_log.warn("invalid ldap retry count. (" + LDAP_RECONNECT_RETRIES_KEY + "=" + properties.getProperty(LDAP_RECONNECT_RETRIES_KEY) + ")");
+						}
+						RECONNECT_MAX = RECONNECT_MAX_DEFAULT;
+					}
+				} catch (NumberFormatException e) {
+					if (m_log.isWarnEnabled()) {
+						m_log.warn("invalid ldap retry count. (" + LDAP_RECONNECT_RETRIES_KEY + "=" + properties.getProperty(LDAP_RECONNECT_RETRIES_KEY) + ")", e);
+					}
+				}
+			} else {
+				if (m_log.isInfoEnabled()) {
+					m_log.info("ldap retry count is not defined. (" + LDAP_RECONNECT_RETRIES_KEY + ")");
+				}
+			}
+		} catch (FileNotFoundException e) {
+			if (m_log.isWarnEnabled()) {
+				m_log.warn("file not found. (" + propertyFile + ")", e);
+			}
+		} catch (IOException e) {
+			if (m_log.isWarnEnabled()) {
+				m_log.warn("failed to load a file. (" + propertyFile + ")", e);
+			}
+		}
+		
+		if (m_log.isInfoEnabled()) {
+			m_log.info("configured ldap reconnect interval. (" + PROVIDER_CONNECT_INTERVAL + " [msec])");
+			m_log.info("configured ldap retry count. (" + RECONNECT_MAX + " [retries])");
+		}
+	}
+	
 	/**
 	 * 唯一の自身のインスタンスを返します。<BR>
 	 * <code> LdapConnectionManager </code>オブジェクトを保持します。
@@ -199,7 +276,8 @@ public class LdapConnectionManager {
 		
 		//LDAP用のコンテキストの作成
 		for (int i = 0; i < RECONNECT_MAX; i++) {
-			TimeKeeper timer = new TimeKeeper(15000); //timeout of 15 secs
+//			TimeKeeper timer = new TimeKeeper(15000); //timeout of 15 secs
+			TimeKeeper timer = TimeKeeperService.start();
 			try {
 				m_log.debug("getDirContext() : LDAP Connect " + jndiName);
 				InitialContext iniCtx = new InitialContext();
@@ -212,11 +290,12 @@ public class LdapConnectionManager {
 				m_log.error("getDirContext() : LDAP Connection Error " + jndiName + " : " + e.getMessage(), e);
 			}
 			finally {
-				timer.setLdapResponse(true);
+//				timer.setLdapResponse(true);
 				Thread.currentThread().interrupted();
 								
 				// タイマースレッドを停止
-				timer.interrupt();
+//				timer.interrupt();
+				TimeKeeperService.stop(timer);
 			}
 		}
 		
@@ -290,50 +369,50 @@ public class LdapConnectionManager {
 		}
 	}
 	
-	class TimeKeeper extends Thread {
-		long timeout; //msec
-		long timerStart;
-		
-		boolean ldapResponse = false;
-		Thread parent;
-		
-		TimeKeeper(long timout) {
-			parent = Thread.currentThread();
-			this.timeout = timout;
-			this.start();
-		}
-		
-		@SuppressWarnings("static-access")
-		public void run() {
-			timerStart = System.currentTimeMillis();
-			
-			long waitTime = timeout;
-			
-			while (waitTime > 0) {
-				try {
-					this.sleep(waitTime);
-				} catch (InterruptedException ie) {
-					// ignore and continue
-					if (isLdapResponse()){
-						break;
-					}
-				}
-				waitTime = timeout - (System.currentTimeMillis() - timerStart);
-			}
-			synchronized (this) {
-				if (!isLdapResponse()){
-					m_log.error("LDAP Connection Timeout. [ " + timeout + " ms ]");
-					parent.interrupt();
-				}
-			}
-		}
-		
-		public boolean isLdapResponse() {
-			return ldapResponse;
-		}
-
-		synchronized public void setLdapResponse(boolean ldapResponse) {
-			this.ldapResponse = ldapResponse;
-		}
-	}
+//	class TimeKeeper extends Thread {
+//		long timeout; //msec
+//		long timerStart;
+//		
+//		boolean ldapResponse = false;
+//		Thread parent;
+//		
+//		TimeKeeper(long timout) {
+//			parent = Thread.currentThread();
+//			this.timeout = timout;
+//			this.start();
+//		}
+//		
+//		@SuppressWarnings("static-access")
+//		public void run() {
+//			timerStart = System.currentTimeMillis();
+//			
+//			long waitTime = timeout;
+//			
+//			while (waitTime > 0) {
+//				try {
+//					this.sleep(waitTime);
+//				} catch (InterruptedException ie) {
+//					// ignore and continue
+//					if (isLdapResponse()){
+//						break;
+//					}
+//				}
+//				waitTime = timeout - (System.currentTimeMillis() - timerStart);
+//			}
+//			synchronized (this) {
+//				if (!isLdapResponse()){
+//					m_log.error("LDAP Connection Timeout. [ " + timeout + " ms ]");
+//					parent.interrupt();
+//				}
+//			}
+//		}
+//		
+//		public boolean isLdapResponse() {
+//			return ldapResponse;
+//		}
+//
+//		synchronized public void setLdapResponse(boolean ldapResponse) {
+//			this.ldapResponse = ldapResponse;
+//		}
+//	}
 }
