@@ -39,12 +39,21 @@ import com.clustercontrol.jobmanagement.message.RunResultInfo;
  */
 public class CommandThread extends AgentThread {
 
+	// ジョブ実行結果を読み取る際のエンコーディングをプロパティに設定する際のキー
+	private final static String INPUT_ENCODING = "input.encoding";
+	
 	protected String m_resultMsg = "";
 	protected String m_errMsg = "";
 	protected int m_exitValue;
+	
+	// ジョブ実行結果を受け取る際のエンコーディング
+	private String m_inputEncoding = null;
 
 	// ロガー
 	static private Log log = LogFactory.getLog(CommandThread.class);
+	
+	// ジョブを起こす（Runtime.execする）際にシリアル化するための専用ロックオブジェクト
+	private static final Object lockNewProcess = new Object();
 
 	/**
 	 * デバッグ用メイン処理
@@ -80,6 +89,11 @@ public class CommandThread extends AgentThread {
 	public CommandThread(RunInstructionInfo info, SendQueue sendQueue,
 			Hashtable<String, Date> runHistory, Properties props) {
 		super(info, sendQueue, runHistory, props);
+		
+		// ログファイルのエンコーディングを設定
+		if(props != null){
+			m_inputEncoding =  props.getProperty(INPUT_ENCODING);
+		}
 	}
 
 	/**
@@ -145,13 +159,13 @@ public class CommandThread extends AgentThread {
 				// 終了を送信
 				info.setStatus(RunStatusConstant.ERROR);
 				info.setTime(new Date());
-				info
-						.setErrorMessage("The execution user of the command and agent's user are different. ");
+				String errMsg = "The execution user of the command and agent's user are different. " +
+				"execUser=[" + m_info.getUser() + "], agentUser=[" + sysUserName + "]";
+				info.setErrorMessage(errMsg);
 				info.setMessage("");
 				m_sendQueue.put(info);
 
-				log
-						.error("The execution user of the command and agent's user are different. ");
+				log	.error(errMsg);
 				log.info("run end");
 
 				// 実行履歴削除メッセージ送信
@@ -212,7 +226,12 @@ public class CommandThread extends AgentThread {
 					log.info("Command Execute:" + cmd[i]);
 				}
 			}
-			process = runtime.exec(cmd);
+			// JVM（Windows環境）の不具合（？）でRuntime.execの並列実行多重度を上げた
+			// 場合に問題が発生することがあるため、同時にただ１つのスレッドのみがexecを実行
+			// できるように、staticなロックオブジェクトのsynchronizedによってシリアル化する
+			synchronized(lockNewProcess) {
+				process = runtime.exec(cmd);
+			}
 		} catch (IOException e) {
 			log.error(e);
 			m_errMsg = e.getMessage();
@@ -334,7 +353,11 @@ public class CommandThread extends AgentThread {
 									+ " : stdout / errout limit("
 									+ m_limit_orgmsg + " Byte) over");
 //							out_string = new String(m_readbuf);
-							out_string = new String(m_readbuf, 0, total);
+							if(m_inputEncoding != null){
+								out_string = new String(m_readbuf, 0, total, m_inputEncoding);
+							} else {
+								out_string = new String(m_readbuf, 0, total);
+							}
 							bufIsFull = true;
 							
 						// バッファがフルでなく、ストリームに残りがある場合は、再度読み込みへ
@@ -345,7 +368,14 @@ public class CommandThread extends AgentThread {
 				}
 				
 				// バッファがフルになっていなければ、バッファをStringに変換
-				if (!bufIsFull) out_string = new String(m_readbuf, 0, total);
+				if (!bufIsFull) {
+					if (m_inputEncoding != null) {
+						out_string = new String(m_readbuf, 0, total, m_inputEncoding);
+					} else {
+						out_string = new String(m_readbuf, 0, total);
+					}
+					
+				}
 
 			} catch (IOException e) {
 				log.error(e);
