@@ -17,6 +17,7 @@ package com.clustercontrol.composite;
 
 import java.io.UnsupportedEncodingException;
 import java.util.ArrayList;
+import java.util.TreeMap;
 
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
@@ -66,7 +67,8 @@ public class StyledTextComposite extends Composite {
 				
 				String lineText = event.lineText;
 				ArrayList<StyleRange> styleRanges = new ArrayList<StyleRange>();
-							
+				TreeMap<Integer, Integer> paramPtr = new TreeMap<Integer, Integer>(); 
+				
 				for(int i=0; i<keywords.length; i++){
 					int index = 0;
 					int fromIndex = 0;
@@ -75,14 +77,21 @@ public class StyledTextComposite extends Composite {
 
 					// キーワードに一致する文字列が含まれる場合はその位置を取得する
 					while ((index = lineText.indexOf(keyword, fromIndex)) != -1) {
-						StyleRange styleRange = new StyleRange();
-						styleRange.start = event.lineOffset + index;
-						styleRange.length = keyword.length();
-						styleRange.foreground = color;
-						styleRanges.add(styleRange);
+						paramPtr.put(event.lineOffset + index, keyword.length());
 						fromIndex = index + keyword.length();
 					}
 				}	
+				
+				// workaround for SWT bug 212851 StyledText - getStyleRanges(int start, int length) returns wrong style range
+				// http://mail.eclipse.org/viewcvs/index.cgi/org.eclipse.swt/Eclipse%20SWT%20Custom%20Widgets/common/org/eclipse/swt/custom/StyledTextRenderer.java?annotate=1.86
+				for (Integer key : paramPtr.keySet()) {
+					StyleRange styleRange = new StyleRange();
+					styleRange.start = key;
+					styleRange.length = paramPtr.get(key);
+					styleRange.foreground = color;
+					styleRanges.add(styleRange);;
+				}
+				
 				event.styles = styleRanges.toArray(new StyleRange[styleRanges.size()]);
 			}
 		});
