@@ -17,17 +17,19 @@ package com.clustercontrol.monitor.run.bean;
 
 import java.sql.Timestamp;
 import java.util.ArrayList;
+import java.util.Collection;
 
 import com.clustercontrol.bean.MonitorBlockConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.RunIntervalConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.bean.YesNoConstant;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 
 /**
  * 監視情報を保持するクラス<BR>
  * 
- * @version 2.1.0
+ * @version 3.0.0
  * @since 2.0.0
  */
 public class MonitorInfo
@@ -54,6 +56,14 @@ implements java.io.Serializable
 	/** ファシリティID。 */
 	protected String m_facilityId;
 	
+	
+	/** 通知グループID*/
+	protected String m_notifyGroupId;
+	
+	/**　通知IDのコレクション*/
+	
+	protected Collection<NotifyRelationInfo> m_notifyId;
+	
 	/** 
 	 * 値失敗時の重要度。
 	 * 
@@ -74,8 +84,6 @@ implements java.io.Serializable
 	/** 監視対象ID。 */
 	protected String m_monitorTypeId;
 	
-	/** 通知ID。 */
-	protected String m_notifyId;
 	
 	/**
 	 * 実行間隔（秒）。
@@ -116,12 +124,6 @@ implements java.io.Serializable
 	/** タイムアウト。 */
 	protected int m_timeout;
 	
-	/**
-	 * ジョブ実行。
-	 *
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	protected int m_jobRun = YesNoConstant.TYPE_NO;
 	
 	/** 値取得の失敗時のメッセージID（未使用）。 */
 	protected String m_failureMessageId;
@@ -129,29 +131,6 @@ implements java.io.Serializable
 	/** 値取得の失敗時のメッセージ（未使用）。 */
 	protected String m_failureMessage;
 	
-	/**
-	 * 値取得の失敗時のジョブ実行（未使用）。
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	protected int m_failureJobRun = YesNoConstant.TYPE_NO;
-	
-	/** 値取得の失敗時のジョブID（未使用）。 */
-	protected String m_failureJobId;
-	
-	/** 
-	 * 値取得の失敗時のジョブの通知抑制と連動（未使用）。
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	protected int m_failureJobInhibitionFlg = YesNoConstant.TYPE_NO;
-	
-	/** 
-	 * 値取得の失敗時のジョブ呼出の失敗時の重要度（未使用）。
-	 * 
-	 * @see com.clustercontrol.bean.PriorityConstant
-	 */
-	protected int m_failureJobFailurePriority = PriorityConstant.TYPE_UNKNOWN;
 	
 	/** 新規作成ユーザ。 */
 	protected String m_regUser;
@@ -176,22 +155,19 @@ implements java.io.Serializable
 	 * @param scope スコープ
 	 * @param facilityId ファシリティID
 	 * @param failurePriority 値取得の失敗時の重要度
-	 * @param jobRun ジョブ実行
 	 * @param monitorBlock 監視単位
 	 * @param monitorId 監視項目ID
 	 * @param monitorTypeId 監視対象ID
 	 * @param monitorType 監視種別
-	 * @param notifyId 通知ID
+
 	 * @param regDate 作成日時
 	 * @param regUser 新規作成ユーザ
 	 * @param runInterval 実行間隔（秒）
 	 * @param timeout タイムアウト
 	 * @param failureMessageId 値取得の失敗時のメッセージID（未使用）
 	 * @param failureMessage  値取得の失敗時のメッセージ（未使用）
-	 * @param failureJobRun 値取得の失敗時のジョブ実行（未使用）
-	 * @param failureJobId 値取得の失敗時のジョブID（未使用）
-	 * @param failureJobInhibitionFlg 値取得の失敗時の通知抑制と連動（未使用）
-	 * @param failureJobFailurePriority 値取得の失敗時のジョブ呼出の失敗時の重要度（未使用）
+	 * @param notifyGroupId 通知グループID
+	 * @param notifyId 通知IDのコレクション
 	 * @param updateDate 最終変更日時
 	 * @param updateUser 最終変更ユーザ
 	 * @param valid 有効/無効
@@ -206,22 +182,18 @@ implements java.io.Serializable
 			String scope,
 			String facilityId,
 			int failurePriority,
-			int jobRun,
 			int monitorBlock,
 			String monitorId,
 			String monitorTypeId,
 			int monitorType,
-			String notifyId,
 			Timestamp regDate,
 			String regUser,
 			int runInterval,
 			int timeout,
 			String failureMessageId, 
 			String failureMessage,
-			Integer failureJobRun,
-			String failureJobId,
-			Integer failureJobInhibitionFlg,
-			Integer failureJobFailurePriority,
+			String notifyGroupId,
+			Collection notifyId,
 			Timestamp updateDate,
 			String updateUser,
 			int valid,
@@ -235,22 +207,18 @@ implements java.io.Serializable
 		setScope(scope);
 		setFacilityId(facilityId);
 		setFailurePriority(failurePriority);
-		setJobRun(jobRun);
 		setMonitorBlock(monitorBlock);
 		setMonitorId(monitorId);
 		setMonitorTypeId(monitorTypeId);
 		setMonitorType(monitorType);
-		setNotifyId(notifyId);
 		setRegDate(regDate);
 		setRegUser(regUser);
 		setRunInterval(runInterval);
 		setTimeout(timeout);
 		setFailureMessageId(failureMessageId);
 		setFailureMessage(failureMessage);
-		setFailureJobRun(failureJobRun);
-		setFailureJobId(failureJobId);
-		setFailureJobInhibitionFlg(failureJobInhibitionFlg);
-		setFailureJobFailurePriority(failureJobFailurePriority);
+		setNotifyGroupId(notifyGroupId);
+		setNotifyId(notifyId);
 		setUpdateDate(updateDate);
 		setUpdateUser(updateUser);
 		setValid(valid);
@@ -272,21 +240,17 @@ implements java.io.Serializable
 		setScope(otherData.getScope());
 		setFacilityId(otherData.getFacilityId());
 		setFailurePriority(otherData.getFailurePriority());
-		setJobRun(otherData.getJobRun());
 		setMonitorBlock(otherData.getMonitorBlock());
 		setMonitorId(otherData.getMonitorId());
 		setMonitorTypeId(otherData.getMonitorTypeId());
 		setMonitorType(otherData.getMonitorType());
-		setNotifyId(otherData.getNotifyId());
 		setRegDate(otherData.getRegDate());
 		setRegUser(otherData.getRegUser());
 		setRunInterval(otherData.getRunInterval());
 		setFailureMessageId(otherData.getFailureMessageId());
 		setFailureMessage(otherData.getFailureMessage());
-		setFailureJobRun(otherData.getFailureJobRun());
-		setFailureJobId(otherData.getFailureJobId());
-		setFailureJobInhibitionFlg(otherData.getFailureJobInhibitionFlg());
-		setFailureJobFailurePriority(otherData.getFailureJobFailurePriority());
+		setNotifyGroupId(otherData.getNotifyGroupId());
+		setNotifyId(otherData.getNotifyId());
 		setUpdateDate(otherData.getUpdateDate());
 		setUpdateUser(otherData.getUpdateUser());
 		setValid(otherData.getValid());
@@ -294,6 +258,27 @@ implements java.io.Serializable
 		setCheckInfo(otherData.getCheckInfo());
 	}
 	
+	/**
+	 * 通知グループIDを設定します。
+	 * 
+	 * @param notifyGroupId
+	 */
+	public void setNotifyGroupId(String notifyGroupId) {
+		
+		 m_notifyGroupId = notifyGroupId;
+		
+	}
+
+	/**
+	 * 通知グループIDを返します。
+	 * 
+	 * @return * 通知グループID
+	 */
+	public String getNotifyGroupId() {
+		
+		return m_notifyGroupId;
+	}
+
 	/**
 	 * アプリケーションを返します。
 	 * 
@@ -469,7 +454,7 @@ implements java.io.Serializable
 	 * 
 	 * @return 通知ID
 	 */
-	public String getNotifyId(){
+	public Collection<NotifyRelationInfo> getNotifyId(){
 		return this.m_notifyId;
 	}
 	
@@ -478,7 +463,7 @@ implements java.io.Serializable
 	 * 
 	 * @param notifyId 通知ID
 	 */
-	public void setNotifyId( String notifyId ){
+	public void setNotifyId( Collection<NotifyRelationInfo> notifyId ){
 		this.m_notifyId = notifyId;
 	}
 	
@@ -656,111 +641,6 @@ implements java.io.Serializable
 		m_updateUser = user;
 	}
 	
-	/**
-	 * ジョブ実行を返します。
-	 * 
-	 * @return ジョブ実行
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public int getJobRun() {
-		return m_jobRun;
-	}
-	
-	/**
-	 * ジョブ実行を設定します。
-	 * 
-	 * @param run ジョブ実行
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public void setJobRun(int run) {
-		m_jobRun = run;
-	}
-	
-	/**
-	 * 値取得の失敗時のジョブ呼出の失敗時の重要度を返します（未使用）。
-	 * 
-	 * @return 値取得の失敗時のジョブ呼出の失敗時の重要度
-	 * 
-	 * @see com.clustercontrol.bean.PriorityConstant
-	 */
-	public int getFailureJobFailurePriority() {
-		return m_failureJobFailurePriority;
-	}
-	
-	/**
-	 * 値取得の失敗時のジョブ呼出の失敗時の重要度を設定します（未使用）。
-	 * 
-	 * @param jobFailurePriority 値取得の失敗時のジョブ呼出の失敗時の重要度
-	 * 
-	 * @see com.clustercontrol.bean.PriorityConstant
-	 */
-	public void setFailureJobFailurePriority(int jobFailurePriority) {
-		m_failureJobFailurePriority = jobFailurePriority;
-	}
-	
-	/**
-	 * 値取得の失敗時のジョブIDを返します（未使用）。
-	 * 
-	 * @return 値取得の失敗時のジョブID
-	 */
-	public String getFailureJobId() {
-		return m_failureJobId;
-	}
-	
-	/**
-	 * 値取得の失敗時のジョブIDを設定します（未使用）。
-	 * 
-	 * @param jobId 値取得の失敗時のジョブID
-	 */
-	public void setFailureJobId(String jobId) {
-		m_failureJobId = jobId;
-	}
-	
-	/**
-	 * 値取得の失敗時のジョブの通知抑制と連動を返します（未使用）。
-	 * 
-	 * @return 値取得の失敗時のジョブの通知抑制と連動
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public int getFailureJobInhibitionFlg() {
-		return m_failureJobInhibitionFlg;
-	}
-	
-	/**
-	 * 値取得の失敗時のジョブの通知抑制と連動を設定します（未使用）。
-	 * 
-	 * @param jobInhibitionFlg 値取得の失敗時のジョブの通知抑制と連動
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public void setFailureJobInhibitionFlg(int jobInhibitionFlg) {
-		m_failureJobInhibitionFlg = jobInhibitionFlg;
-	}
-	
-	/**
-	 * 値取得の失敗時のジョブ実行を返します（未使用）。
-	 * 
-	 * @return 値取得の失敗時のジョブ実行
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public int getFailureJobRun() {
-		return m_failureJobRun;
-	}
-	
-	/**
-	 * 値取得の失敗時のジョブ実行を設定します（未使用）。
-	 * 
-	 * @param jobRun 値取得の失敗時のジョブ実行
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public void setFailureJobRun(int jobRun) {
-		m_failureJobRun = jobRun;
-	}
 	
 	/**
 	 * 値取得の失敗時のメッセージを返します（未使用）。
