@@ -667,7 +667,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
     	info.setNotifyType(m_notifyType);
         
         // 通知基本情報
-        validateResult = super.m_notifyBasic.createInputData(info);
+        validateResult = super.m_notifyBasic.createInputData(info, this.notifyId);
         if(validateResult != null){
         	return null;
         }
