@@ -230,9 +230,6 @@ public class RunMonitorHttp extends RunMonitorNumericValueType {
 			if(m_request.getHeader() != null && !"".equals(m_request.getHeader().trim())){
 				response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeader().trim());
 			}
-			if(m_request.getFooter() != null && !"".equals(m_request.getFooter().trim())){
-				response.append("\n" + Messages.getString("footer") + " :\n" + m_request.getFooter().trim());
-			}
 			if(m_request.getResponseBody() != null && !"".equals(m_request.getResponseBody().trim())){
 				response.append("\n" + Messages.getString("response.body") + " :\n" + m_request.getResponseBody().trim());
 			}
@@ -247,9 +244,6 @@ public class RunMonitorHttp extends RunMonitorNumericValueType {
 			if(m_request.getHeader() != null && !"".equals(m_request.getHeader().trim())){
 				response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeader().trim());
 			}
-			if(m_request.getFooter() != null && !"".equals(m_request.getFooter().trim())){
-				response.append("\n" + Messages.getString("footer") + " :\n" + m_request.getFooter().trim());
-			}
 			m_messageOrg = response.toString();
 		}
 		return result;
