@@ -413,6 +413,66 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		}
 	}
 	
+	/**
+	 * 引数で指定されたセッションIDに該当するジョブ変数一覧を取得します。<br>
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean#ejbFindBySessionId(java.lang.String)
+	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#findBySessionId(java.lang.String)
+	 */
+	public Collection findBySessionId(String session_id) throws FinderException {
+		
+		/** Local Variables */
+		ArrayList<JobParamInfoPK> ret = new ArrayList<JobParamInfoPK>();
+		
+		Connection conn = null;
+		PreparedStatement stmt = null;
+		ResultSet res = null;
+		
+		/** Main */
+		if (m_log.isDebugEnabled()) m_log.debug("finding parameters of job session... (session_id = " + session_id + ")");
+		
+		try {
+			conn = ConnectionManager.getConnectionManager().getConnection();	
+			
+			String sql = "SELECT session_id, job_id, param_id FROM cc_job_param_info WHERE session_id = ?";
+			stmt = conn.prepareStatement(sql);
+			stmt.setString(1, session_id);
+			
+			res = stmt.executeQuery();
+			
+			while(res.next()) {
+				JobParamInfoPK pk= new JobParamInfoPK(
+						res.getString("session_id"),
+						res.getString("job_id"), 
+						res.getString("param_id")
+				);
+				ret.add(pk);
+			}
+			
+			if (m_log.isDebugEnabled()) m_log.debug("found " + ret.size() + "parameters of job session... (session_id = " + session_id + ")");
+			
+		} catch (SQLException e) {
+			if (m_log.isWarnEnabled()) m_log.warn("failed to find parameters of job session... (session_id = " + session_id + ")", e);
+			throw new EJBException("failed to find parameters of job session... (session_id = " + session_id + ")");
+		}  finally{
+			try {
+				if(stmt != null){
+					stmt.close();}
+				if(res != null){
+					res.close();}
+				if(conn != null){
+					conn.close();
+				}
+			} catch (SQLException e) {
+				if (m_log.isWarnEnabled()) m_log.warn("failed to find parameters of job session... (session_id = " + session_id + ")", e);
+				throw new EJBException("failed to find parameters of job session... (session_id = " + session_id + ")");
+			}
+		}
+		if (m_log.isDebugEnabled()) m_log.debug("successful in finding parameters of job session. (session_id = " + session_id + ")");
+		
+		return ret;
+	}
+	
 	/**
 	 * 複数件取得するSELECT文を発行します。
 	 * 引数で指定されたセッションIDとジョブIDで、データベースを検索します。
