@@ -37,9 +37,9 @@ import javax.naming.InitialContext;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.OutputNotifyGroupInfo;
 import com.clustercontrol.logagent.util.InternalLogger;
-import com.clustercontrol.monitor.bean.QueueConstant;
-import com.clustercontrol.monitor.message.LogOutputInfo;
+import com.clustercontrol.notify.bean.QueueConstant;
 
 /**
  * マネージャとのやり取りに利用するQueue送信クラス<BR>
@@ -53,7 +53,7 @@ import com.clustercontrol.monitor.message.LogOutputInfo;
  * com.clustercontrol.monitor.bean.QueueConstant.QUEUE_NAME_LOG<BR>
  * に接続する。
  *
- * @version 2.1.0
+ * @version 3.0.0
  * @since 2.1.0
  */
 public class SendQueue implements ExceptionListener {
@@ -63,9 +63,12 @@ public class SendQueue implements ExceptionListener {
 	private static final String QUEUE_USER_NAME = "queue.user.name";
 
 	private static final String QUEUE_USER_PASSWORD = "queue.user.password";
-	
-	private static final long SEND_TIMEOUT = 60 * 1000l;
 
+	private static final long SEND_TIMEOUT = 60 * 1000l;
+	private static final long RECONNECT_TIMEOUT = 60 * 1000l;
+	
+	private Agent m_agent;
+	
 	private Properties m_props;
 
 	private QueueConnection m_con;
@@ -84,21 +87,29 @@ public class SendQueue implements ExceptionListener {
 
 	//ロガー
 	static private Log log = LogFactory.getLog(SendQueue.class);
-	
+
 	// reInitialメソッドが複数スレッドから呼ばれないよにするロック用オブジェクト
-	private Object reInitialLock = new Object();
+	private final Object reInitialLock = new Object();
+
+	// Queue送信処理が複数スレッドから呼ばれないよにするロック用オブジェクト
+	private final Object sendQueueLock = new Object();  
+	
+	// Queueコネクションに対する処理が複数スレッドから呼ばれないようにするためのロック用オブジェクト  
+	// 再接続処理でコネクションを生成し直すと別オブジェクトとなる
+	private volatile Object connectionLock = new Object();  
 	
 	// 内部エラー出力抑制フラグ
 	// エージェント → マネージャ間通信に失敗した場合にエラー出力を行うが、
 	// 継続して通信できていない状態の場合は出力を制御する
 	volatile private boolean internalErroInhibitflag = false;
-    
+	
 	/**
 	 * コンストラクタ
 	 * @param props プロパティファイル情報
 	 */
-	public SendQueue(Properties props) {
+	public SendQueue(Agent agent, Properties props) {
 		super();
+		m_agent = agent;
 		m_props = props;
 		
 		// ReciveTopic再接続処理実行間隔取得
@@ -119,28 +130,39 @@ public class SendQueue implements ExceptionListener {
 	 *  再接続処理
 	 */
 	private boolean reInitial() {
-		synchronized (reInitialLock) {
-			boolean ret = false;
-
-			log.info("再接続処理!");
-
-			terminate();
-
-			if (initial()) {
-
-				ret = true;
-
-				log.info("再接続処理:成功!");
-
-				//エラーフラグ解除
-				m_isErr = false;
-
-
-			} else {
-				log.info("再接続処理:失敗!");
+		// 単一スレッドのみ以下の処理が実行できるように、クラスインスタンスのロックオブジェクトで、
+		// 同期化しシリアルに動作するようにする。
+		synchronized(reInitialLock){
+			if(m_isErr == false){
+				// 別スレッドで接続が復旧しているため、何もせずに処理を抜ける
+				return true;
 			}
+			
+			log.debug("reInitial() start");
 
-			return ret;
+			ExecutorService es = null;
+			Future<Boolean> task = null;
+			try {
+				// Executorオブジェクトの生成
+				ReconnectorThreadFactory threadFactory = 
+					new ReconnectorThreadFactory(Thread.currentThread().getName());
+				es = Executors.newSingleThreadExecutor(threadFactory);
+				task = es.submit(new Reconnector());
+
+				return task.get(RECONNECT_TIMEOUT, TimeUnit.MILLISECONDS);
+			} catch (Exception e) {
+				log.error(e.getMessage(), e);
+				m_isErr = true;
+				return false;
+			} finally {
+				// タスクをキャンセル
+				task.cancel(true);
+				
+				if (es != null) {
+					es.shutdown();
+				}
+				log.debug("reInitial() end");
+			}
 		}
 	}
 	/**
@@ -153,66 +175,100 @@ public class SendQueue implements ExceptionListener {
 			if (m_session != null)
 				m_session.close();
 		} catch (JMSException e) {
+			log.error(e.getMessage(), e);
 		}
 
 		try {
 			if (m_con != null)
 				m_con.close();
-		} catch (JMSException e1) {
+		} catch (JMSException e) {
+			log.error(e.getMessage(), e);
 		}
 	}
 
-    /**
-     * メッセージをマネージャに送信します。<BR>
-     * 
+	/**
+	 * メッセージをマネージャに送信します。<BR>
+	 * 
 	 * 実行応答メッセージを送信する。<BR>
 	 * 処理失敗は1回再試行する。
 	 * 
 	 * @param msg
 	 */
-	synchronized public boolean put(Object info) {
-		log.debug("put() start : " + info.toString());
+	public boolean put(Object info) {
+		// 単一スレッドのみ以下の処理が実行できるように、クラスインスタンスのロックオブジェクト（sendQueueLock）で、
+		// 同期化しシリアルに動作するようにする。
+		synchronized(sendQueueLock){
+			log.debug("put() start : " + info.toString());
+			
+			while (true) {
+				ExecutorService es = null;
+				Future<Boolean> task = null;
+				try {
+					// Executorオブジェクトの生成
+					String id = "";
+					if (info instanceof OutputNotifyGroupInfo) {
+						id = ((OutputNotifyGroupInfo)info).getMonitorId();
+					} else {
+						id = info.toString();
+					}
+					
+					SenderThreadFactory threadFactory = new SenderThreadFactory(id);
+					es = Executors.newSingleThreadExecutor(threadFactory);
 
-		ExecutorService es = null;
-        Future<?> task = null;
-        try {
-    		// Executorオブジェクトの生成
-        	String id = "";
-			if (info instanceof LogOutputInfo) {
-				id = ((LogOutputInfo)info).getMonitorId();
-			} else {
-				id = info.toString();
-			}
-			SenderThreadFactory threadFactory = new SenderThreadFactory(id);
-            es = Executors.newSingleThreadExecutor(threadFactory);
-        	
-            // タスクの実行
-            task = es.submit(new Sender(info));
-			task.get(SEND_TIMEOUT, TimeUnit.MILLISECONDS);
-			return true;
-		} catch (Exception e) {
-			if(internalErroInhibitflag == true){
-				// 抑制されている場合は簡略なメッセージとする
-				log.error("Failed to connect to MGR");
-			} else {
-				log.error("Failed to connect to MGR", e);
-			}
+					// Queue送信タスクを実行する。
+					// 別スレッドでQueue送信処理を実行することで、送信処理に無限の時間がかかっても、
+					// Future.get()のタイムアウトにより、本スレッドに制御が戻るようにする。
+					log.debug("put() submit : " + id);
+					task = es.submit(new Sender(info));
+					boolean sendQueueStatus = task.get(SEND_TIMEOUT, TimeUnit.MILLISECONDS);
 
-			// 抑制されていない場合に出力する
-			if(internalErroInhibitflag == false){
-				// syslogにログ出力
-				InternalLogger.error("hinemos_logagent: Failed to connect to MGR");
-				// エラーログ出力抑制フラグを設定する
-				internalErroInhibitflag = true;
-			}
-		} finally {
-			log.debug("put() end   : " + info.toString());
-			if(es != null){
-				es.shutdown();
+					// Queue送信に成功した場合はループを抜ける
+					if(sendQueueStatus == true){
+						return true;
+					}
+				} catch (Exception e) {
+					// Queue送信処理で例外が発生した場合、もしくは、Future.get()でタイムアウトが発生した場合に、
+					// ここに制御が移る
+					
+					if(internalErroInhibitflag == true){
+						// 抑制されている場合は簡略なメッセージとする
+						log.error("Failed to connect to MGR");
+					} else {
+						log.error("Failed to connect to MGR", e);
+					}
+
+					// 抑制されていない場合に出力する
+					if(internalErroInhibitflag == false){
+						// syslogにログ出力
+						InternalLogger.error("hinemos_logagent: Failed to connect to MGR");
+						// エラーログ出力抑制フラグを設定する
+						internalErroInhibitflag = true;
+					}
+					
+					// 一定時間sleepした後、QueueConnection、QueueSession を再接続する。
+					try {
+						Thread.sleep(m_interval);
+					} catch (InterruptedException e1) {
+						// 何もしない
+						log.error(e1.getMessage(), e1);
+					}
+
+					m_isErr = true;
+					reInitial();
+
+					log.info("オブジェクトメッセージ送信リトライ");
+				} finally {
+					// タスクをキャンセル
+					task.cancel(true);
+					
+					if (es != null) {
+						es.shutdown();
+					}
+					
+					log.debug("put() end    : " + info.toString());
+				}
 			}
 		}
-		
-		return false;
 	}
 
 
@@ -221,7 +277,7 @@ public class SendQueue implements ExceptionListener {
 	 * 
 	 * @return
 	 */
-    private boolean initial() {
+	private boolean initial() {
 
 		log.info("EJB接続初期化");
 
@@ -247,21 +303,20 @@ public class SendQueue implements ExceptionListener {
 
 			
 			//セッション生成
-			m_session = m_con.createQueueSession(false,
-					Session.AUTO_ACKNOWLEDGE);
+			m_session = m_con.createQueueSession(false, Session.AUTO_ACKNOWLEDGE);
 			
 			//エラーハンドラセット
-	        m_con.setExceptionListener(this);
+			m_con.setExceptionListener(this);
 			
 			//コネクション開始
 			m_con.start();
 
 			//メッセージQueue取得
-			m_queueLog = (Queue) con.lookup(QueueConstant.QUEUE_NAME_LOG);
+			m_queueLog = (Queue) con.lookup(QueueConstant.QUEUE_NAME_EVENT);
 			m_queueFacility = (Queue) con.lookup(com.clustercontrol.logtransfer.bean.QueueConstant.QUEUE_NAME_FILE_MANAGE);
 
-			
-			
+			// エラー出力抑制フラグをクリア
+			internalErroInhibitflag = false;
 
 		} catch (Exception e) {
 			log.error("Init", e);
@@ -271,59 +326,70 @@ public class SendQueue implements ExceptionListener {
 			try {
 				if (con != null)
 					con.close();
-			} catch (Exception e1) {
+			} catch (Exception e) {
+				log.error(e.getMessage(), e);
 			}
 		}
-		// エラー出力抑制フラグをクリア
-		internalErroInhibitflag = false;
-		
 		return true;
 
 	}
-	
-    /* 通信エラーハンドラ
-     * (non-Javadoc)
-     * @see javax.jms.ExceptionListener#onException(javax.jms.JMSException)
-     */
-    public void onException(JMSException arg0) {
 
-    	log.error(arg0.getMessage(), arg0);
-    	  	
-    	m_isErr = true;
-        
-        terminate();
-    }
-    
-    /**
-     * Queueメッセージ送信処理を実行するタスク用クラス
-     */
-    private class Sender implements Callable<Boolean> {
-    	private Object m_info;
-    	
-    	public Sender(Object info){
-    		m_info = info;
-    	}
-    	
+	/* 通信エラーハンドラ
+	 * (non-Javadoc)
+	 * @see javax.jms.ExceptionListener#onException(javax.jms.JMSException)
+	 */
+	public void onException(JMSException arg0) {
+
+		log.error(arg0.getMessage(), arg0);
+
+		m_agent.reConnection();
+
+	}
+
+	/**
+	 * 再接続処理を行う
+	 */
+	public void reconnect() {
+		m_isErr = true;
+	}
+	
+	/**
+	 * Queueメッセージ送信処理を実行するタスク用クラス
+	 */
+	private class Sender implements Callable<Boolean> {
+		private Object m_info;
+
+		public Sender(Object info){
+			m_info = info;
+		}
+
 		public Boolean call() throws Exception {
 			if (m_isErr) {
-				reInitial();
+				if(reInitial() == false){
+					// 再接続に失敗した場合
+					return false;
+				}
+			}
+
+			if(m_session == null){
+				return false;
 			}
 
 			QueueSender sender = null;
-			Message mess = null;
-
-			while(true) {
-				try {
-					
-					if (m_info instanceof LogOutputInfo) {
+			try {
+				// 複数スレッドがQueueConnection, QueueSessionのインスタンスにアクセスしないように、
+				// 送信処理を同期化する。
+				synchronized(connectionLock){
+					Message mess = null;
+					if (m_info instanceof OutputNotifyGroupInfo) {
 						//監視機能へ送信
 						//Sender作成
 						sender = m_session.createSender(m_queueLog);
 						//メッセージ作成
-						mess = m_session.createObjectMessage((LogOutputInfo)m_info);
-						
+						mess = m_session.createObjectMessage((OutputNotifyGroupInfo)m_info);
+
 						if (log.isDebugEnabled()) {
-							LogOutputInfo loginfo = (LogOutputInfo)m_info;
+							OutputNotifyGroupInfo loginfo = (OutputNotifyGroupInfo)m_info;
 							log.debug("オブジェクトメッセージ送信! : "
 									+ "Facility ID : " + loginfo.getFacilityId() + ", "
 									+ "Monitor ID : " + loginfo.getMonitorId() + ", "
@@ -331,7 +397,6 @@ public class SendQueue implements ExceptionListener {
 									+ "Message ID : " + loginfo.getMessageId() + ", "
 									+ "Message : " + loginfo.getMessage());
 						}
-						
 					}else if (m_info instanceof String) {
 						//ログ転送へファシリティID送信
 						//Sender作成
@@ -343,43 +408,28 @@ public class SendQueue implements ExceptionListener {
 					}else{
 						return false;
 					}
-					
 
-					// 詳細情報を上記のlog出力含めるため、ここではコメントアウトとする
-//					log.info("オブジェクトメッセージ送信!");
 					//送信
 					sender.send(mess);
-					
-					return true;
-		
-				} catch (JMSException e) {
-					log.error(e);
-					log.info("オブジェクトメッセージ送信リトライ");
-					
-					try {
-//						wait(m_interval);
-						Thread.sleep(m_interval);
-					} catch (InterruptedException e1) {
-					}
-					
-					if(!reInitial()){
-						return false;
-					}
-		
-				} finally {
-					try {
-						if (sender != null)
-							sender.close();
-					} catch (Exception e1) {
-					}
+				}
+
+				return true;
+			} catch (Exception e) {
+				throw e;
+			} finally {
+				try {
+					if (sender != null)
+						sender.close();
+				} catch (Exception e) {
+					log.error(e.getMessage(), e);
 				}
 			}
 		}
-    }
-    
-    /**
-     * Queueメッセージ送信処理を実行するタスク用のThreadFactory
-     */
+	}
+
+	/**
+	 * Queueメッセージ送信処理を実行するタスク用のThreadFactory
+	 */
 	private class SenderThreadFactory implements ThreadFactory {
 		private final String m_threadName;
 		
@@ -391,4 +441,47 @@ public class SendQueue implements ExceptionListener {
 			return new Thread(r, "Sender-" + m_threadName);
 		}
 	}
+	
+	/**
+	 * 再接続処理を実行するタスク用クラス
+	 */
+	private class Reconnector implements Callable<Boolean> {
+		public Boolean call() throws Exception {
+			boolean ret = false;
+
+			log.info("再接続処理!");
+
+			terminate();
+
+			if (initial()) {
+
+				ret = true;
+
+				log.info("再接続処理:成功!");
+
+				//エラーフラグ解除
+				m_isErr = false;
+
+			} else {
+				log.info("再接続処理:失敗!");
+			}
+
+			return ret;
+		}
+	}
+
+	/**
+	 * 再接続処理を実行するタスク用のThreadFactory
+	 */
+	private class ReconnectorThreadFactory implements ThreadFactory {
+		private final String m_threadName;
+		
+		public ReconnectorThreadFactory(String threadName){
+			m_threadName = threadName;
+		}
+		
+		public Thread newThread(Runnable r) {
+			return new Thread(r, "Reconnector-" + m_threadName);
+		}
+	}
 }
