@@ -102,11 +102,11 @@ public class EventLogDAOImpl implements EventLogDAO {
 
 			} else {
 				String msg = "EventLog data is not found.";
-				m_log.error("load() error : " + pk.toString() + " SQLException " + msg);
+				m_log.error("load() error : " + pk.toString() + msg);
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
-			m_log.error("load() error : " + pk.toString() + " SQLException");
+			m_log.error("load() error : " + pk.toString() , e);
 			throw new EJBException(e.getMessage());
 		} finally {
 			// コネクション、結果セット、プリペアドステートメントのクロース
@@ -121,7 +121,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("load() error : " + pk.toString() + " SQLException " + e1.getMessage());
+				m_log.error("load() error : " + pk.toString() , e1);
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -189,14 +189,13 @@ public class EventLogDAOImpl implements EventLogDAO {
 				String msg = "result row is not 1";
 				m_log.error("store() error : " + ejb.getPluginId() + ", "
 						+ ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", "
-						+ ejb.getOutputDate() + " SQLException" + msg);
+						+ ejb.getOutputDate() + " " + msg);
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("store() error : " + ejb.getPluginId() + ", "
 					+ ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", "
-					+ ejb.getOutputDate() + " SQLException");
-			e.printStackTrace();
+					+ ejb.getOutputDate() , e);
 			throw new EJBException(e.getMessage());
 		} finally {
 			// コネクション、結果セット、プリペアドステートメントのクロース
@@ -210,8 +209,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			} catch (SQLException e1) {
 				m_log.error("store() error : " + ejb.getPluginId() + ", "
 						+ ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", "
-						+ ejb.getOutputDate() + " SQLException");
-				e1.printStackTrace();
+						+ ejb.getOutputDate() , e1);
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -246,11 +244,11 @@ public class EventLogDAOImpl implements EventLogDAO {
 			
 			if (row != 1 ) {
 				String msg = "result row is not 1";
-				m_log.error("remove() error : " + pk.toString() + " SQLException" + msg);
+				m_log.error("remove() error : " + pk.toString() + " " + msg);
 				throw new EJBException(msg);	
 			}
 		} catch (SQLException e) {
-			m_log.error("remove() error : " + pk.toString() + " SQLException");
+			m_log.error("remove() error : " + pk.toString() , e);
 			throw new EJBException(e.getMessage());
 			
 		} finally {
@@ -262,7 +260,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("remove() error : " + pk.toString() + " SQLException");
+				m_log.error("remove() error : " + pk.toString() , e1);
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -337,14 +335,17 @@ public class EventLogDAOImpl implements EventLogDAO {
 			
 			if (row != 1) {
 				String msg = "result row is not 1";
-				m_log.error("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate() + " SQLException");
+				m_log.error("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate());
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
+			//想定されるエラー処理(再挿入するためDuplicateKeyを検知し、DuplicateKeyExceptionスローする)
 			if(e.getSQLState().equals("23505")){
-				m_log.info("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate() + " SQLException" + "DuplicateKeyException ");
+				m_log.info("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate() + " SQLException" + " DuplicateKeyException");
 				throw new DuplicateKeyException(e.getMessage());
 			}
+			//想定外のエラー処理
+			m_log.error("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate(),e);
 			throw new CreateException(e.getMessage());
 		}finally{
 			try {
@@ -355,7 +356,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate() + " SQLException");
+				m_log.error("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate() , e1);
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -400,7 +401,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("findAll() error :  SQLException");
+			m_log.error("findAll() error : " , e);
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -412,7 +413,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("findAll() error :  SQLException");
+				m_log.error("findAll() error : " , e1);
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -459,7 +460,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 				throw new FinderException(msg);
 			}
 		} catch (SQLException e) {
-			m_log.error("find() error : " + pk.toString() + " SQLException");
+			m_log.error("find() error : " + pk.toString() , e);
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -471,7 +472,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("find() error : " + pk.toString() + " SQLException");
+				m_log.error("find() error : " + pk.toString() , e1);
 				throw new EJBException(e1.getMessage());
 			}
 			m_log.debug("findByPrimaryKey() end : " + pk.toString());
@@ -537,7 +538,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("findByGenerationDateOrder() error :  SQLException");
+			m_log.error("findByGenerationDateOrder() error : " , e);
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -549,7 +550,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("findByGenerationDateOrder() error :  SQLException");
+				m_log.error("findByGenerationDateOrder() error : " , e1);
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -628,7 +629,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("selectByMessageOrg() error :  SQLException");
+			m_log.error("selectByMessageOrg() error : " , e);
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -640,7 +641,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("selectByMessageOrg() error :  SQLException");
+				m_log.error("selectByMessageOrg() error : " , e1);
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -845,7 +846,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("selectEvent() error :  SQLException");
+			m_log.error("selectEvent() error : " , e);
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -857,7 +858,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("selectEvent() error :  SQLException");
+				m_log.error("selectEvent() error : " , e1);
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -1039,7 +1040,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("countEvent() error :  SQLException");
+			m_log.error("countEvent() error : " , e);
 			throw e;
 		}  finally{
 			try {
@@ -1051,7 +1052,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("countEvent() error :  SQLException");
+				m_log.error("countEvent() error : " , e1);
 				throw e1;
 			}
 		}
@@ -1227,8 +1228,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			// クエリを実行
 			row = stmt.executeUpdate();
 		} catch (SQLException e) {
-			m_log.error("confirmEvent() error :  SQLException");
-			m_log.error(e.getMessage());
+			m_log.error("confirmEvent() error : ", e);
 			throw e;
 		}  finally{
 			try {
@@ -1240,8 +1240,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("confirmEvent() error :  SQLException");
-				m_log.error(e1.getMessage());
+				m_log.error("confirmEvent() error : " , e1);
 				throw e1;
 			}
 		}
@@ -1413,7 +1412,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("selectHighPriorityEvent() error :  SQLException");
+			m_log.error("selectHighPriorityEvent() error : " , e);
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -1425,7 +1424,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("selectHighPriorityEvent() error :  SQLException");
+				m_log.error("selectHighPriorityEvent() error : " , e1);
 				throw new EJBException(e1.getMessage());
 			}
 		}
