@@ -422,7 +422,7 @@ public class SendMail extends InhibitAction{
 				if (mailInfo.getMailTemplateId() != null) 
 				{
 					MailTemplateInfoData mailData = MailTemplateControllerUtil.getLocalHome().create().getMailTemplateInfo(mailInfo.getMailTemplateId());
-					buf.append(substitution(mailData.getBody(), source));
+					buf.append(substitution(mailData.getBody() + "\n", source));
 				}
 				else
 				{
