@@ -16,6 +16,7 @@
 package com.clustercontrol.performance.dialog;
 
 import java.util.ArrayList;
+import java.util.List;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionEvent;
@@ -39,9 +40,10 @@ import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.performance.composite.tree.CollectorBasicScopeComposite;
 import com.clustercontrol.performance.composite.tree.CollectorRuleComposite;
 import com.clustercontrol.performance.composite.tree.CollectorTreeComposite;
-import com.clustercontrol.performanceMGR.bean.CollectorProperty;
-import com.clustercontrol.performanceMGR.bean.CollectorType;
-import com.clustercontrol.performanceMGR.ejb.bmp.RecordCollectorData;
+import com.clustercontrol.performance.bean.CollectorItemInfo;
+import com.clustercontrol.performance.bean.CollectorProperty;
+import com.clustercontrol.performance.bean.CollectorType;
+import com.clustercontrol.performance.ejb.bmp.RecordCollectorData;
 import com.clustercontrol.util.Messages;
 
 /**
@@ -406,7 +408,7 @@ public class RecordSetDialog extends CommonDialog {
         // 設定値が既に設定されている場合はそれを画面に設定
         if(inputData != null){
         	// 収集期間
-        	this.setPeriod(inputData.getCollectorData().getPeriod());
+        	this.setPeriod(inputData.getCollectorData().getPeriodMin());
         }
 	}
 	
@@ -552,7 +554,7 @@ public class RecordSetDialog extends CommonDialog {
              	return null;
         }
 	else {
-        	info.getCollectorData().setPeriod(getPeriod());
+        	info.getCollectorData().setPeriodMin(getPeriod());
         		info.getCollectorData().setPresavePeriod(0);
         	}
         }else{//無期限に収集する。
@@ -573,12 +575,12 @@ public class RecordSetDialog extends CommonDialog {
 		else{
         		info.getCollectorData().setPresavePeriod(getPresave());
         		//閾値監視の収集期間が-1のため、無期限は-1とする。
-        		info.getCollectorData().setPeriod(-1);
+        		info.getCollectorData().setPeriodMin(-1);
         	}
         }
         
     	// 収集項目を設定
-        ArrayList itemList = itemTreeComposite.getItemList();
+        List<CollectorItemInfo> itemList = itemTreeComposite.getItemList();
         if(itemList.size() == 0){
         	validateResult = new ValidateResult();
         	validateResult.setValid(false);
