@@ -21,6 +21,7 @@ import java.util.ArrayList;
 
 import javax.ejb.CreateException;
 import javax.ejb.DuplicateKeyException;
+import javax.ejb.EJBException;
 import javax.ejb.FinderException;
 import javax.naming.NamingException;
 
@@ -66,6 +67,10 @@ public class AddNodeProperty {
 				// アクセス権なしの場合、エラーダイアログを表示する
 	            MessageDialog.openInformation(null, Messages.getString("message"),
 	                    Messages.getString("message.accesscontrol.16"));
+	            
+			} else if (e.getCause() instanceof EJBException) {
+				MessageDialog.openError(null, Messages.getString("failed"),  Messages.getString("message.repository.5") + "\n\n--\n" + e.getMessage());
+				return result;
 			}
         } catch (NamingException e) {
         } catch (FinderException e) {
