@@ -29,6 +29,8 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.util.LdapConnectionManager;
+import com.clustercontrol.accesscontrol.util.TimeKeeper;
+import com.clustercontrol.accesscontrol.util.TimeKeeperService;
 import com.clustercontrol.repository.bean.DeviceInfoAttributeConstant;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoBean;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoPK;
@@ -64,13 +66,16 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				clearBean(ejb);
 				
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 	
@@ -147,8 +152,11 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("load() context close failed : " + e.getMessage());
+					m_log.error("load() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return;
 		}
@@ -161,11 +169,14 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-				
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(ejb.getDn());
 				
@@ -280,8 +291,10 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("store() context close failed : " + e.getMessage());
+					m_log.error("store() context close failed : " + e.getMessage(), e);
 				}
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return;
 		}
@@ -294,10 +307,14 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//エントリを削除
 				ctx.destroySubcontext(pk.getDn());
 				return;
@@ -341,8 +358,11 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("remove() context close failed : " + e.getMessage());
+					m_log.error("remove() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 		}
 	}
@@ -355,6 +375,7 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;	
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
@@ -382,7 +403,32 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 				
 				//dn設定
 				ejb.setDn(dn.toString());
-	
+				
+				//各種属性値をセットする
+				
+				if (ejb.getDeviceName() != null) {
+					attrs.put(DeviceInfoAttributeConstant.DEVICENAME, ejb.getDeviceName());
+				}
+				
+				if (ejb.getSnmpOID() != null) {
+					attrs.put(DeviceInfoAttributeConstant.SNMPOID, ejb.getSnmpOID());
+				}
+				
+				if (ejb.getDeviceIndex() != null) {
+					attrs.put(DeviceInfoAttributeConstant.DEVICEINDEX, ejb.getDeviceIndex().toString());
+				}
+				
+				if (ejb.getDeviceType() != null) {
+					attrs.put(DeviceInfoAttributeConstant.DEVICETYPE, ejb.getDeviceType());
+				}
+				
+				if (ejb.getDescription() != null) {
+					attrs.put(DeviceInfoAttributeConstant.DESCRIPTION, ejb.getDescription());
+				}
+				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//エントリ作成
 				ctx.createSubcontext(ejb.getDn(), attrs);
 	
@@ -443,8 +489,11 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("create() context close failed : " + e.getMessage());
+					m_log.error("create() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 		}
 		return pk;
@@ -479,11 +528,14 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -542,9 +594,12 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findAll() context close failed : " + e.getMessage());
+					m_log.error("findAll() context close failed : " + e.getMessage(), e);
 				}
-			}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
+			}	
 		}
 		return ret;
 	}
@@ -558,13 +613,17 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				m_log.debug("findByPrimaryKey() : dn = " + pk.getDn());
 				
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				// タイマースレッドを停止
+				timer = TimeKeeperService.start();
+				
 				//属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 				
@@ -614,8 +673,11 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("findByPrimaryKey() context close failed : " + e.getMessage());
+					m_log.error("findByPrimaryKey() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return pk;
 		}
@@ -660,11 +722,14 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(baseDn.toString(), search.toString(), constraints);
 				
 				if (results == null ) {
@@ -723,8 +788,11 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findByFacilityId() context close failed : " + e.getMessage());
+					m_log.error("findByFacilityId() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return ret;
 		}
@@ -770,11 +838,14 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(baseDn.toString(), search.toString(), constraints);
 				
 				//検索結果を取得
@@ -830,8 +901,11 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findByFacilityIdAndName() context close failed : " + e.getMessage());
+					m_log.error("findByFacilityIdAndName() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return pk;
 		}
