@@ -1567,11 +1567,38 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		}
 		
 		//IPアドレスを取得
-		values = PropertyUtil.getPropertyValue(property, NodeProperty.IP_ADDRESS_V4);
-		String ip4Address = checkString(values.get(0));
-		if (ip4Address == null) {
-			throw new EJBException("facilityId=" + facilityId + " : ip4Address is null");
-		}
+		values = PropertyUtil.getPropertyValue(property, NodeProperty.IP_ADDRESS_VERSION);
+		Object obj = values.get(0);
+	    Integer ipAddressVersion = null; 
+        
+        if(obj.getClass() == Integer.class){
+        	ipAddressVersion = (Integer)obj;
+        }
+		
+        if(ipAddressVersion == null || ipAddressVersion == 4) {
+        	
+    		values = PropertyUtil.getPropertyValue(property, NodeProperty.IP_ADDRESS_V4);
+    		String ip4Address = checkString(values.get(0));
+    		if (ip4Address == null) {
+    			throw new EJBException("facilityId=" + facilityId + " : ip4Address is null");
+    		}
+        	
+        }
+        else if(ipAddressVersion == 6){
+        	
+    		values = PropertyUtil.getPropertyValue(property, NodeProperty.IP_ADDRESS_V6);
+    		String ip6Address = checkString(values.get(0));
+    		if (ip6Address == null) {
+    			throw new EJBException("facilityId=" + facilityId + " : ip6Address is null");
+    		}
+        	
+        }
+        else {
+        	
+        	throw new EJBException("facilityId=" + facilityId + " : ipAddressVersion is incorrect");
+        	
+        }
+        
 		
 		//ノード名を取得
 		values = PropertyUtil.getPropertyValue(property, NodeProperty.NODE_NAME);
