@@ -267,17 +267,19 @@ public class ModifyFacility {
     	AccessLock.lock(AccessLock.REPOSITORY);
 		
 		String facilityId = null;
-	    try {
+		try {
 			ArrayList values = null;
+			
 			//現在日時を取得
 			Date now = new Date();
 			
 			//ファシリティID取得
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_ID);
-			facilityId = (String)values.get(0);
+			facilityId = checkString(values.get(0));
 			//ファシリティ名取得
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_NAME);
-			String facilityName = (String)values.get(0);
+			String facilityName = checkString(values.get(0));
+			
 			
 			//Facilityを作成
 			FacilityLocal facility = FacilityUtil.getLocalHome().create(
@@ -417,11 +419,11 @@ public class ModifyFacility {
 //			FIXME　ソートの順番はとりあえずオンコードで100とする。
 		
 			facility.setSortValue(new Integer(DEFAULT_SORT_ORDER));
-			
-			//nullをセットすることでstore()を呼び出す。
-			facility = null;
-
-			//デバイスの配列を取得
+//			
+//			//nullをセットすることでstore()を呼び出す。
+//			facility = null;
+//
+//			//デバイスの配列を取得
 			ArrayList deviceList = PropertyUtil.getProperty(property, NodeProperty.DEVICE);
 			for(int i = 0; i < deviceList.size(); i++){
 			    //デバイスINDEXを取得
@@ -433,31 +435,27 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
 				String deviceType = checkString(values.get(0));
 				
-				if(deviceIndex != null && deviceType != null && !deviceType.equals("")){
-					//DeviceInfoを作成
-					DeviceInfoLocal device = DeviceInfoUtil.getLocalHome().create(
-							deviceIndex, 
-							deviceType,
-							facilityId);
+				//デバイス名を取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
+				String deviceName = checkString(values.get(0));
+				//デバイスOIDを取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
+				String snmpOID = checkString(values.get(0));
+				//説明を取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
+				String description = checkString(values.get(0));
 				
-					if(device != null){
-						//デバイス名を取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
-						device.setDeviceName(checkString(values.get(0)));
-					    //デバイスINDEXを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_INDEX);
-						device.setDeviceIndex(checkInteger(values.get(0)));
-						//デバイスOIDを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
-						device.setSnmpOID(checkString(values.get(0)));
-						//デバイスタイプを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
-						device.setDeviceType(checkString(values.get(0)));
-						//説明を取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
-						device.setDescription(checkString(values.get(0)));
-					}
+				// デバイスを登録しない場合はcontinue
+				if (deviceIndex == null && deviceName == null &&
+						deviceType == null && snmpOID == null && description == null) {
+					continue;
 				}
+				
+				//dn, cnはDeviceInfoDAOImplで生成する
+				DeviceInfoLocal device = DeviceInfoUtil.getLocalHome()
+						.create(deviceIndex, deviceName, deviceType, snmpOID, description,
+								facilityId);
+				
 			}
 			
 			//ファイルシステムの配列を取得
@@ -468,26 +466,26 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_INDEX);
 				Integer cn = checkInteger(values.get(0));
 				
-				if(cn != null){
-					//FileSystemInfoを作成
-					FileSystemInfoLocal fileSystem = FileSystemInfoUtil.getLocalHome().create(
-							cn, 
-							facilityId);
+				//マウント位置を取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
+				String fileSystemMountPoint = checkString(values.get(0));
+				//ファイルシステムOIDを取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
+				String snmpOID = checkString(values.get(0));
+				//ファイルシステムタイプを取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
+				String fileSystemType = checkString(values.get(0));
+				//説明を取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
+				String description = checkString(values.get(0));
 				
-					if(fileSystem != null){
-					    //マウント位置を取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
-						fileSystem.setFileSystemMountPoint(checkString(values.get(0)));
-						//ファイルシステムOIDを取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
-						fileSystem.setSnmpOID(checkString(values.get(0)));
-						//ファイルシステムタイプを取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
-						fileSystem.setFileSystemType(checkString(values.get(0)));
-						//説明を取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
-						fileSystem.setDescription(checkString(values.get(0)));
-					}
+				if(cn != null){
+					//dnはFileSystemInfoDAOImplで生成する
+					FileSystemInfoLocal fileSystem = FileSystemInfoUtil
+							.getLocalHome().create(cn, fileSystemMountPoint,
+									fileSystemType, snmpOID, description,
+									facilityId);
+					
 				}
 			}
 			
@@ -702,31 +700,27 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
 				String deviceType = checkString(values.get(0));
 				
-				if(deviceIndex != null && deviceType != null && !deviceType.equals("")){
-					//DeviceInfoを作成
-					DeviceInfoLocal device = DeviceInfoUtil.getLocalHome().create(
-							deviceIndex, 
-							deviceType,
-							facilityId);
-	
-					if(device != null){
-					    //デバイス名を取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
-						device.setDeviceName(checkString(values.get(0)));
-					    //デバイスINDEXを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_INDEX);
-						device.setDeviceIndex(checkInteger(values.get(0)));
-						//デバイスOIDを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
-						device.setSnmpOID(checkString(values.get(0)));
-						//デバイスタイプを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
-						device.setDeviceType(checkString(values.get(0)));
-						//説明を取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
-						device.setDescription(checkString(values.get(0)));
-					}
+				//デバイス名を取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
+				String deviceName = checkString(values.get(0));
+				//デバイスOIDを取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
+				String snmpOID = checkString(values.get(0));
+				//説明を取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
+				String description = checkString(values.get(0));
+				
+				// デバイスを登録しない場合はcontinue
+				if (deviceIndex == null && deviceName == null &&
+						deviceType == null && snmpOID == null && description == null) {
+					continue;
 				}
+				
+				//dn, cnはDeviceInfoDAOImplで生成する
+				DeviceInfoLocal device = DeviceInfoUtil.getLocalHome()
+						.create(deviceIndex, deviceName, deviceType, snmpOID, description,
+								facilityId);
+				
 			}
 			
 			//Facilityと関連しているファイルシステムを削除
@@ -748,8 +742,6 @@ public class ModifyFacility {
 			} catch (RemoveException e) {
 			    m_log.debug("modifyNode() : " + e.getMessage());
 			}
-			//nullをセットすることでstore()を呼び出す。
-			facility = null;
 			
 			//ファイルシステムの配列を取得
 			ArrayList fileSystemList = PropertyUtil.getProperty(property, NodeProperty.FILE_SYSTEM);
@@ -761,26 +753,25 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_INDEX);
 				Integer cn = checkInteger(values.get(0));
 				
-				if(cn != null){					
-					//FileSystemInfoを作成
-					FileSystemInfoLocal fileSystem = FileSystemInfoUtil.getLocalHome().create(
-							cn, 
-							facilityId);
+				//マウント位置を取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
+				String fileSystemMountPoint = checkString(values.get(0));
+				//ファイルシステムOIDを取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
+				String snmpOID = checkString(values.get(0));
+				//ファイルシステムタイプを取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
+				String fileSystemType = checkString(values.get(0));
+				//説明を取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
+				String description = checkString(values.get(0));
 				
-					if(fileSystem != null){
-					    //マウント位置を取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
-						fileSystem.setFileSystemMountPoint(checkString(values.get(0)));
-						//ファイルシステムOIDを取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
-						fileSystem.setSnmpOID(checkString(values.get(0)));
-						//ファイルシステムタイプを取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
-						fileSystem.setFileSystemType(checkString(values.get(0)));
-						//説明を取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
-						fileSystem.setDescription(checkString(values.get(0)));
-					}
+				if(cn != null){
+					//dnはFileSystemInfoDAOImplで生成する
+					FileSystemInfoLocal fileSystem = FileSystemInfoUtil
+							.getLocalHome().create(cn, fileSystemMountPoint,
+									fileSystemType, snmpOID, description,
+									facilityId);
 				}
 			}
 			
