@@ -30,8 +30,8 @@ import com.clustercontrol.bean.FacilityConstant;
 import com.clustercontrol.bean.FacilityInfo;
 import com.clustercontrol.bean.FacilityTreeItem;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.performanceMGR.bean.DeviceData;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
+import com.clustercontrol.repository.ejb.entity.DeviceInfoData;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoLocal;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoUtil;
 import com.clustercontrol.repository.ejb.entity.FacilityLocal;
@@ -208,6 +208,51 @@ public class SelectFacility {
 					//ccSnmpVersion取得
 					map.put(attribute, facility.getSnmpVersion());
 				}
+				else if(attribute.compareTo(FacilityAttributeConstant.VALID) == 0){
+					//ccValid取得
+					map.put(attribute, facility.getValid());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.SNMPTIMEOUT) == 0){
+					//ccSnmpTImeout取得
+					map.put(attribute, facility.getSnmpTimeout());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.SNMPRETRIES) == 0){
+					//ccSnmpRetries取得
+					map.put(attribute, facility.getSnmpRetries());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.SNMPPROXY) == 0){
+					//ccSnmpProxy取得
+					map.put(attribute, facility.getSnmpProxy());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.NOTE) == 0){
+					//ccNote取得
+					map.put(attribute, facility.getNote());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.ICONIMAGE) == 0){
+					//ccIconImage取得
+					map.put(attribute, facility.getIconImage());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.VIRTNODETYPE) == 0){
+					//ccVirtualizationNodeType取得
+					map.put(attribute, facility.getVirtNodeType());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.VMMANAGEMENTNODE) == 0){
+					//ccVmManagementNode取得
+					map.put(attribute, facility.getVMManagementNode());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.VMINDEX) == 0){
+					//ccVMID取得
+					map.put(attribute, facility.getVmIndex());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.VMNAME) == 0){
+					//ccVMName取得
+					map.put(attribute, facility.getVmName());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.VIRTSOLUTION) == 0){
+					//ccVirtualizationSolution取得
+					map.put(attribute, facility.getVirtSolution());
+				}				
+				
 			}
 		} catch (FinderException e) {
 			throw e;
@@ -244,30 +289,33 @@ public class SelectFacility {
 	/**
 	 * デバイス一覧を取得
 	 * 
-	 * DeviceDataの配列を返す
+	 * DeviceInfoDataの配列を返す
 	 * 
 	 * @param facilityId
-	 * @return DeviceDataの配列
+	 * @return DeviceInfoDataの配列
 	 * @throws FinderException
 	 * @throws NamingException
 	 */
-	public ArrayList<DeviceData> getDeviceList(String facilityId) throws FinderException, NamingException {
-		ArrayList<DeviceData> list = null;
+	public ArrayList<DeviceInfoData> getDeviceList(String facilityId) throws FinderException, NamingException {
+		ArrayList<DeviceInfoData> list = null;
 		try {
 			//デバイスのデータをリポジトリから取得
 			//FacilityTreeの最上位エントリを取得
 			Collection ct = DeviceInfoUtil.getLocalHome().findByFacilityId(facilityId);
 			
-			list = new ArrayList<DeviceData>();
+			list = new ArrayList<DeviceInfoData>();
 			Iterator itr = ct.iterator();
 			while(itr.hasNext()){
 				DeviceInfoLocal d = (DeviceInfoLocal)itr.next();
-				DeviceData data = new DeviceData(
+				DeviceInfoData data = new DeviceInfoData(
+						d.getDn(), 
+						d.getCn(), 
 						d.getFacilityId(), 
-						d.getSnmpOID(), 
-						d.getDeviceIndex().intValue(), 
+						d.getDescription(), 
+						d.getDeviceIndex(), 
 						d.getDeviceName(), 
-						d.getDeviceType());
+						d.getDeviceType(), 
+						d.getSnmpOID());
 				
 				list.add(data);
 			}
@@ -279,15 +327,19 @@ public class SelectFacility {
 			itr = ct.iterator();
 			while(itr.hasNext()){
 				FileSystemInfoLocal f = (FileSystemInfoLocal)itr.next();
-				DeviceData data = new DeviceData(
+				DeviceInfoData data = new DeviceInfoData(
+						f.getDn(), 
+						f.getCn().toString(), 	// cnをStringで渡す
 						f.getFacilityId(), 
-						f.getSnmpOID(), 
-						f.getCn(), 		// FileSystemIndex
-						f.getFileSystemMountPoint(), 
-						DeviceTypeConstant.DEVICE_FILESYSTEM);
+						f.getDescription(), 
+						f.getCn(),				// FileSystemIndex
+						f.getFileSystemMountPoint(),
+						DeviceTypeConstant.DEVICE_FILESYSTEM,
+						f.getSnmpOID());
 				
 				list.add(data);
 			}
+			
 		} catch (FinderException e) {
 			throw e;
 		} catch (NamingException e) {
@@ -297,6 +349,7 @@ public class SelectFacility {
 		return list;
 	}
 	
+	
 	/**
 	 * ノード一覧を取得
 	 * 
@@ -405,9 +458,12 @@ public class SelectFacility {
 			//説明取得
 			values = PropertyUtil.getPropertyValue(property, NodeFilterProperty.DESCRIPTION);
 			String description = (String)values.get(0);
-			//IPアドレス取得
-			values = PropertyUtil.getPropertyValue(property, NodeFilterProperty.IP_ADDRESS);
-			String ipAddress = (String)values.get(0);
+			//IPアドレス v4 取得
+			values = PropertyUtil.getPropertyValue(property, NodeFilterProperty.IP_ADDRESS_V4);
+			String ipAddressV4 = (String)values.get(0);
+			//IPアドレス v6 取得
+			values = PropertyUtil.getPropertyValue(property, NodeFilterProperty.IP_ADDRESS_V6);
+			String ipAddressV6 = (String)values.get(0);
 			//OS名取得
 			values = PropertyUtil.getPropertyValue(property, NodeFilterProperty.OS_NAME);
 			String osName = (String)values.get(0);
@@ -427,7 +483,8 @@ public class SelectFacility {
 						facilityId, 
 						facilityName, 
 						description, 
-						ipAddress, 
+						ipAddressV4, 
+						ipAddressV6, 
 						osName, 
 						osRelease, 
 						managerName, 
@@ -525,23 +582,43 @@ public class SelectFacility {
 	 * 
 	 * @param parentFacilityId
 	 * @param level
+	 * @param valid 有効/無効フラグ 有効:true, 無効:false, 指定なし:null
 	 * @return
 	 * @throws FinderException
 	 * @throws NamingException
 	 */
-	public ArrayList getNodeFacilityIdList(String parentFacilityId, int level, boolean sort) throws FinderException, NamingException {
+	public ArrayList getNodeFacilityIdList(String parentFacilityId, int level, boolean sort, Boolean valid) throws FinderException, NamingException {
 		ArrayList list = null;
 		try {
 			Collection ct = null;
+			
+			// 配下すべてのエントリ
 			if(level == RepositoryControllerBean.ALL){
-				//FacilityTreeの最上位エントリを取得
-				ct = FacilityTreeUtil.getLocalHome().findAllNode(parentFacilityId);
-			}
-			else{
-				//FacilityTreeの最上位エントリを取得
-				ct = FacilityTreeUtil.getLocalHome().findOneLevelNode(parentFacilityId);
+				
+				if (valid == null) {
+					//FacilityTreeの最上位エントリを取得
+					ct = FacilityTreeUtil.getLocalHome().findAllNode(parentFacilityId);
+					
+				} else {
+					//有効/無効フラグを指定する場合
+					ct = FacilityTreeUtil.getLocalHome().findAllNodeByValid(parentFacilityId, valid);
+				}
+			
+			// 直下のみ
+			} else {
+				if (valid == null) {
+					//FacilityTreeの最上位エントリを取得
+					ct = FacilityTreeUtil.getLocalHome().findOneLevelNode(parentFacilityId);
+
+				} else {
+					//有効/無効フラグを指定する場合
+					ct = FacilityTreeUtil.getLocalHome().findOneLevelNodeByValid(parentFacilityId, valid);
+			
+				}
+				
 			}
 			
+			//FacilityIdの重複を排除する
 			HashMap map = new HashMap();
 			list = new ArrayList();
 			Iterator itr = ct.iterator();
@@ -571,8 +648,7 @@ public class SelectFacility {
 	
 	/**
 	 * ファシリティIDリスト取得
-	 * 
-	 * ファシリティIDの配列として返す
+	 * sort値を指定し、全ノードのファシリティIDを配列として返す
 	 * 
 	 * @return
 	 * @throws FinderException
@@ -820,6 +896,8 @@ public class SelectFacility {
 			info.setSortOrder(facilityTree.getSortValue());
 			//組み込みスコープフラグ
 			info.setBuiltInFlg(facilityTree.isBuiltIn());
+			//ノード単位の有効／無効
+			info.setValid(facilityTree.getValid());
 			
 			item = new FacilityTreeItem(parent, info);
 		}
