@@ -15,11 +15,15 @@
 
 package com.clustercontrol.snmptrap.factory;
 
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
+import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 
@@ -113,6 +117,12 @@ public class TrapSnmpManager {
 	 */
 	private int m_port = 162;
 	
+	/**
+	 * SNMPTRAPカウンタ(受信数)
+	 */
+	private long snmptrapCounter = 0;
+	private int statsInterval = 100;
+	
 	/**
 	 * コンストラクタ
 	 * @param port 待ち受けポート番号
@@ -122,6 +132,35 @@ public class TrapSnmpManager {
 		m_port = port;
 	}
 	
+	/**
+	 * hinemos.propertiesからsnmptrap.stats.intervalというプロパティ値を取得して返す。
+	 * デフォルト値は100。
+	 * SNMPTRAP受信数/100の間隔でログファイルにSNMP受信数を出力する。
+	 * @return
+	 */
+	private int getStatsInterval () {
+		Properties properties = new Properties();
+		String etcdir = System.getProperty("hinemos.manager.etc.dir");
+		String propertyFile = etcdir + File.separator + "hinemos.properties";
+		FileInputStream stream = null;
+		try {
+			stream = new FileInputStream(propertyFile);
+			properties.load(stream);
+			statsInterval = Integer.parseInt(properties.getProperty("snmptrap.stats.interval","100"));
+			m_log.debug("getStatsInterval() : " + statsInterval);
+		} catch (Exception e) {
+		} finally {
+			if (stream != null) {
+				try {
+					stream.close();
+				} catch (IOException e) {
+				}
+				stream = null;
+			}
+		}
+		return statsInterval;
+	}
+	
 	/**
 	 * 開始処理
 	 */
@@ -131,6 +170,9 @@ public class TrapSnmpManager {
 			m_sendQueue = new SendQueue(QueueConstant.QUEUE_NAME_NOTIFY);
 			m_repository = RepositoryControllerUtil.getLocalHome().create();
 			
+			// 統計情報の出力間隔を設定ファイルから読み込む。
+			getStatsInterval();
+			
 			// キャッシュ取得
 			
 			updateCache();
@@ -196,6 +238,11 @@ public class TrapSnmpManager {
 		m_log.debug("find() : received generic : " + Integer.toString(genericId) );
 		m_log.debug("find() : received specific: " + Integer.toString(specificId) );
 		
+		snmptrapCounter++;
+		if (statsInterval != 0 && snmptrapCounter % statsInterval == 0) {
+			m_log.info("find() : The number of received snmptrap : " + snmptrapCounter);
+		}
+		
 		if(m_snmpTrapInfoMap == null)
 			return true;
 		
